# Table of Contents

- [microsoft-defender-for-cloud-apps-mdca-integration-for-saas-discovery](<./microsoft-defender-for-cloud-apps-mdca-integration-for-saas-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Microsoft Defender for Cloud Apps (MDCA) Integration for SaaS Discovery](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery.md>)
  - [Introduction](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Introduction.md>)
  - [Implementation Details](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Implementation-Details.md>)
  - [Discovery Capabilities](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Discovery-Capabilities.md>)
  - [Setting up Microsoft Entra ID Integration](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Setting-up-Microsoft-Entra-ID-Integration.md>)
  - [Register SAP LeanIX in Microsoft Entra ID](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Register-SAP-LeanIX-in-Microsoft-Entra-ID.md>)
  - [Grant Permissions to SAP LeanIX](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Grant-Permissions-to-SAP-LeanIX.md>)
  - [Gather Configuration Settings](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Gather-Configuration-Settings.md>)
  - [Enter the Copied Credentials in SAP LeanIX](<./Microsoft-Defender-for-Cloud-Apps-MDCA-Integration-for-SaaS-Discovery/Enter-the-Copied-Credentials-in-SAP-LeanIX.md>)
